@@ -61,9 +61,6 @@ def replace_transfer_path(module):
         \n"""
             % (path, __file__)
         )
-        # Also, introduce a variable to fix the issue noted by Raymond Hettinger
-        # in https://twitter.com/raymondh/status/1501700903870468099
-        self.error_at_end_of_line = False
 
     module.ModifiedInterpreter.transfer_path = transfer_path
     return module
@@ -98,10 +95,9 @@ def replace_runsource(module):
         "Extend base class method: Stuff the source in the line cache first"
         from code import InteractiveInterpreter
 
-        if self.error_at_end_of_line:
-            # For problem reported by R. Hettinger on Twitter.
-            self.error_at_end_of_line = False
-            self.tkconsole.text.tag_remove("ERROR", "1.0", "end")
+        # There is no point in keeping highlighting of previous SyntaxError
+        # location when new code is entered.
+        self.tkconsole.text.tag_remove("ERROR", "1.0", "end")
 
         filename = self.stuffsource(source)
 
@@ -135,7 +131,6 @@ def replace_showsyntaxerror(module):
 
         tkconsole = self.tkconsole
         text = tkconsole.text
-        text.tag_remove("ERROR", "1.0", "end")
         type, value, tb = sys.exc_info()
         lineno = getattr(value, "lineno", "") or 1
         offset = getattr(value, "offset", "") or 0
@@ -146,8 +141,6 @@ def replace_showsyntaxerror(module):
         else:
             pos = "iomark linestart + %d lines + %d chars" % (lineno - 1, offset - 1)
 
-        # For problem reported by R. Hettinger on Twitter.
-        self.error_at_end_of_line = text.get(pos) == "\n"
         tkconsole.colorize_syntax_error(text, pos)
         tkconsole.resetoutput()
 
